@@ -82,7 +82,7 @@ class CLI:
             script_name='pywinschedule_start'
         )
     @classmethod
-    def start(cls):
+    def startdaemon(cls):
         for watch_dir in get_watch_dirs():
             args=['pywinschedule','watch',watch_dir]
             print(['pywinschedule','watch',watch_dir])
@@ -98,6 +98,10 @@ class CLI:
         ipc.subscribe('stop_all_watcher', kill_all_process)
         ipc.listen()
     @classmethod
+    def start(cls):
+        subprocess.Popen(['pywinschedule','startdaemon'])
+
+    @classmethod
     def stop(cls):
         ipc.dispatch('stop_all_watcher','')
     @classmethod
