@@ -1,5 +1,5 @@
 from pywinschedule.utils.sqlitekvstore import KeyValueStore
-
+import datetime
 class DBList:
     def __init__(self,path):
         self.kv=KeyValueStore(path)
@@ -14,7 +14,7 @@ class DBList:
     def list(self):
         return list(self.kv.keys())
     def add(self,record):
-        self.kv[record]='1'
+        self.kv[record]=datetime.datetime.now().isoformat()
     def remove(self,record):
         del self.kv[record]
     def contains(self,record):
